@@ -21,13 +21,16 @@
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/cpp.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/cpp.py 3842 2008/12/20 22:59:52 scons"
 
 __doc__ = """
 SCons C Pre-Processor module
 """
 
-import SCons.compat
+# TODO(1.5):  remove this import
+# This module doesn't use anything from SCons by name, but we import SCons
+# here to pull in zip() from the SCons.compat layer for early Pythons.
+import SCons
 
 import os
 import re
